# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: agatha_protobuf/analysis/chat.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'agatha_protobuf/analysis/chat.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#agatha_protobuf/analysis/chat.proto\x12\x04\x63hat\x1a\x1bgoogle/protobuf/empty.proto\"\xb6\x01\n\x0b\x43hatRequest\x12\r\n\x05input\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x17\n\nsession_id\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x31\n\x08metadata\x18\x04 \x03(\x0b\x32\x1f.chat.ChatRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\r\n\x0b_session_id\".\n\x0c\x43hatResponse\x12\r\n\x05\x63hunk\x18\x01 \x01(\t\x12\x0f\n\x07is_last\x18\x02 \x01(\x08\"\x91\x01\n\x14\x43reateSessionRequest\x12\x0c\n\x04user\x18\x01 \x01(\t\x12:\n\x08metadata\x18\x02 \x03(\x0b\x32(.chat.CreateSessionRequest.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"}\n\x15\x43reateSessionResponse\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x0f\n\x07summary\x18\x03 \x01(\t\x12\x12\n\nscoreLevel\x18\x04 \x01(\x05\x12\x11\n\tcreatedAt\x18\x05 \x01(\t\x12\x11\n\tupdatedAt\x18\x06 \x01(\t2\x88\x01\n\x0b\x43hatService\x12/\n\x04\x43hat\x12\x11.chat.ChatRequest\x1a\x12.chat.ChatResponse0\x01\x12H\n\rCreateSession\x12\x1a.chat.CreateSessionRequest\x1a\x1b.chat.CreateSessionResponseBEZCgithub.com/blueprint-ai-org/protobuf/build/agatha_protobuf/analysisb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'agatha_protobuf.analysis.chat_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZCgithub.com/blueprint-ai-org/protobuf/build/agatha_protobuf/analysis'
  _globals['_CHATREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_CHATREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CREATESESSIONREQUEST_METADATAENTRY']._loaded_options = None
  _globals['_CREATESESSIONREQUEST_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_CHATREQUEST']._serialized_start=75
  _globals['_CHATREQUEST']._serialized_end=257
  _globals['_CHATREQUEST_METADATAENTRY']._serialized_start=195
  _globals['_CHATREQUEST_METADATAENTRY']._serialized_end=242
  _globals['_CHATRESPONSE']._serialized_start=259
  _globals['_CHATRESPONSE']._serialized_end=305
  _globals['_CREATESESSIONREQUEST']._serialized_start=308
  _globals['_CREATESESSIONREQUEST']._serialized_end=453
  _globals['_CREATESESSIONREQUEST_METADATAENTRY']._serialized_start=195
  _globals['_CREATESESSIONREQUEST_METADATAENTRY']._serialized_end=242
  _globals['_CREATESESSIONRESPONSE']._serialized_start=455
  _globals['_CREATESESSIONRESPONSE']._serialized_end=580
  _globals['_CHATSERVICE']._serialized_start=583
  _globals['_CHATSERVICE']._serialized_end=719
# @@protoc_insertion_point(module_scope)
